 /* Create tables */ 
CREATE TABLE users (
                "uid" Integer PRIMARY KEY, 
                "value" TEXT UNIQUE);


CREATE TABLE workgroups (
                   "wid" Integer PRIMARY KEY, 
                   "value" TEXT UNIQUE);

				   
CREATE TABLE domains (
                   "did" Integer PRIMARY KEY, 
                   "value" TEXT UNIQUE);
				   
				   
CREATE TABLE data (
			  "id" TEXT UNIQUE PRIMARY KEY,
			  "pid" TEXT DEFAULT NULL, 
              "owner" Integer DEFAULT NULL REFERENCES users(uid) ON DELETE SET NULL, 
              "lastmoduser" Integer DEFAULT NULL REFERENCES users(uid) ON DELETE SET NULL, 
              "color" Integer DEFAULT 0, 
              "icon" Integer DEFAULT NULL, 
              "createdate" DATETIME DEFAULT (DATETIME('now')), 
              "moddate" DATETIME DEFAULT (DATETIME('now')), 
              "pos" Integer DEFAULT 0, 
              "datatype" Integer DEFAULT 4, 
              "desc" TEXT, 
              "atexttype" Integer DEFAULT 0, 
              "allowedapps" TEXT, 
              "declinedapps" TEXT, 
              "timingtype" Integer DEFAULT 0,  /* This field is actually used for other purpose. Add an aditional field for the timing function */
              "timinginterval" Integer DEFAULT 0,
			  "cm" Integer DEFAULT 0,
			  "editlid" Integer DEFAULT 1,
			  "tag" Integer DEFAULT -1,
			  "restorepath" TEXT,
			  "comment" TEXT DEFAULT NULL,
			  "trigger" BLOB DEFAULT NULL); 		  

			  
CREATE TABLE folders (
				"id" TEXT UNIQUE REFERENCES data("id") ON DELETE CASCADE, 				
                "popupvis" Integer DEFAULT -1, 
                "active" Integer DEFAULT -1,
				"istemplate" Integer DEFAULT 0,
                "info" TEXT,
                "ltextadd" TEXT, 
                "rtextadd" TEXT,
				
				"sortfield" Integer DEFAULT 0,
				"sortdir" Integer DEFAULT 0,
				"sortmode" Integer DEFAULT 0,
				"sortfield2" Integer DEFAULT -2,
                "sortdir2" Integer DEFAULT 0,		
				
				"constr" TEXT,
				"querystr" TEXT,
				"fieldmap" TEXT,
				"cachedyndata" Integer DEFAULT 0,
				"cachedate" DATETIME DEFAULT (DATETIME('now')));
				
				
CREATE TABLE files (
				"id" TEXT UNIQUE REFERENCES data("id") ON DELETE CASCADE,
                "popupvis" Integer DEFAULT -1, 
                "active" Integer DEFAULT -1, 
                "info" TEXT, 
                "ltextadd" TEXT, 
                "rtextadd" TEXT, 
				
				"sortfield" Integer DEFAULT 0,
				"sortdir" Integer DEFAULT 0,
				"sortmode" Integer DEFAULT 0,
				"sortfield2" Integer DEFAULT -2,
                "sortdir2" Integer DEFAULT 0,		
				
                "password" TEXT, 
                "passcheck" Integer DEFAULT 0, 
                "localpath" TEXT, /* This field is actually used for other purpose. */
                "networkpath" TEXT, /* This field is used for sync location */
                "urlpath" TEXT, /* This field is used for Extended File Extra Data */
                "ftppath" TEXT, 
                "sqlpath" TEXT, 
                "filetype" Integer DEFAULT 0, /* This field is actually used for other purpose. */
                "doudp" Integer DEFAULT 0, 
				
				"syncdate" DATETIME DEFAULT (DATETIME('now')),
				"chid" Integer DEFAULT 0,
                "hubchrowid" Integer DEFAULT 0); 
	
CREATE TABLE levels (
                "lid" Integer PRIMARY KEY, 
                "hk" Integer DEFAULT 0, 				
                "desc" TEXT);
							

CREATE TABLE datalevels (
				"id" TEXT REFERENCES data("id") ON DELETE CASCADE,				
				"lid" Integer REFERENCES levels("lid") ON DELETE CASCADE,
				"desc" TEXT);
CREATE UNIQUE INDEX datalevels_idx ON datalevels("id", "lid");
				

CREATE TABLE phrases (
				"id" TEXT REFERENCES data("id") ON DELETE CASCADE,
				"lid" Integer REFERENCES levels(lid) ON DELETE CASCADE, 				
                "plain" TEXT, 
                "rtf" BLOB, 
                "html" TEXT, 
				"rtf1" TEXT, 
				"rtfd" BLOB, 
				"lang" TEXT, 
                "viewmode" Integer DEFAULT 0);
CREATE UNIQUE INDEX phrases_idx ON phrases("id", "lid");
				
CREATE TABLE vars (
				"id" TEXT UNIQUE REFERENCES data("id") ON DELETE CASCADE,
                "value" Integer DEFAULT 0, 
                "inc" Integer DEFAULT 1);
				

CREATE TABLE embfiles (
                "fid" Integer PRIMARY KEY, 
				"id" TEXT REFERENCES data("id") ON DELETE CASCADE,
				"lid" Integer REFERENCES levels(lid) ON DELETE CASCADE, 
                "type" Integer DEFAULT 0, 
                "data" BLOB, 
                "filename" TEXT NOT NULL);


CREATE TABLE floats (
			   "id" TEXT REFERENCES data("id") ON DELETE CASCADE,
               "uid" Integer REFERENCES users(uid) ON DELETE CASCADE, 
               "x" Integer DEFAULT 0, 
               "y" Integer DEFAULT 0, 
               "width" Integer DEFAULT 96, 
               "height" Integer DEFAULT 20);
				   
CREATE TABLE datausers (
				  "id" TEXT REFERENCES data("id") ON DELETE CASCADE, 
                  "uid" Integer REFERENCES users(uid) ON DELETE CASCADE, 
                  "rights" Integer);
				  
				  
CREATE TABLE dataworkgroups (
					   "id" TEXT REFERENCES data("id") ON DELETE CASCADE, 	
                       "wid" Integer REFERENCES workgroups(wid) ON DELETE CASCADE, 
                       "rights" Integer);
					   
					   
CREATE TABLE datadomains (
			    	"id" TEXT REFERENCES data("id") ON DELETE CASCADE,
                    "did" Integer REFERENCES domains(did) ON DELETE CASCADE, 
                    "rights" Integer);
					
				
CREATE TABLE options (
                "oid" Integer PRIMARY KEY, 
                "version" Integer, 
                "sd" TEXT,
				"historynum" Integer DEFAULT 0,
				"historydays" Integer DEFAULT 0);			

CREATE TABLE datahistory (
                "hid" Integer PRIMARY KEY, 
				"id" TEXT REFERENCES data("id") ON DELETE CASCADE,					
				"lid" Integer REFERENCES levels(lid) ON DELETE CASCADE, 
                "lastmoduser" Integer DEFAULT NULL REFERENCES users(uid) ON DELETE CASCADE, 
                "color" Integer DEFAULT 0, 
                "icon" Integer DEFAULT NULL,               
                "moddate" DATETIME,                             
                "desc" TEXT, 
                "atexttype" Integer DEFAULT 0, 
                "allowedapps" TEXT, 
                "declinedapps" TEXT, 
                "timingtype" Integer DEFAULT 0, 
                "timinginterval" Integer DEFAULT 0,
				"comment" TEXT DEFAULT NULL,
				"trigger" BLOB);

CREATE TABLE phraseshistory (
                "hid" Integer REFERENCES datahistory(hid) ON DELETE CASCADE, 				
                "plain" TEXT, 
                "rtf" BLOB, 
                "html" TEXT,
				"rtf1" TEXT, 
				"rtfd" TEXT, 
                "viewmode" Integer DEFAULT 0);
				
CREATE TABLE historyfiles (                
                "hid" Integer REFERENCES datahistory(hid) ON DELETE CASCADE, 
                "type" Integer DEFAULT 0, 
                "data" BLOB, 
                "filename" TEXT NOT NULL);

CREATE TABLE userstats (
			   "id" TEXT,
               "uid" Integer REFERENCES users(uid) ON DELETE CASCADE, 
               "count" Integer DEFAULT 1, 
			   "synccount" Integer DEFAULT 1, 
               "lastexec" DATETIME DEFAULT (DATETIME('now')));	
CREATE UNIQUE INDEX userstats_idx ON userstats("id", "uid");

 
CREATE TABLE tags (
              "tid" Integer PRIMARY KEY, 
			  "name" TEXT UNIQUE); 

CREATE TABLE datatags (
				"id" TEXT REFERENCES data("id") ON DELETE CASCADE,				
				"tid" Integer REFERENCES tags(tid) ON DELETE CASCADE);
				
CREATE TABLE taglevels (
                "tid" Integer REFERENCES tags(tid) ON DELETE CASCADE, 				
				"lid" Integer REFERENCES levels(lid) ON DELETE CASCADE,
				"name" TEXT);
CREATE UNIQUE INDEX taglevels_idx ON taglevels("tid", "lid");
				
CREATE TABLE comments (
              "cid" Integer PRIMARY KEY, 
			  "id" TEXT REFERENCES data("id") ON DELETE CASCADE,
			  "uid" Integer NOT NULL REFERENCES users(uid) ON DELETE CASCADE,			  
			  "lid" Integer REFERENCES levels(lid) ON DELETE CASCADE,
			  "flag" Integer DEFAULT 0, 
			  "commentdate" DATETIME DEFAULT (DATETIME('now')), 
			  "moddate" DATETIME DEFAULT (DATETIME('now')), 
			  "text" TEXT); 	


CREATE TABLE deleteditems (
			  "id" TEXT,			  
              "deldate" DATETIME DEFAULT (DATETIME('now')),
              "desc" TEXT,
              "datatype" Integer DEFAULT 4
              ); 		  		  
			  
CREATE TABLE syncedchanges (
			  "filename" TEXT,
			  "uuid" TEXT,			                
              "syncdate" DATETIME DEFAULT (DATETIME('now'))
              ); 
